
function [status, frameEachCam] = playData(whatData, whatShow, each_handle_camera, handles, counter)

global state

global currentTime
global allTextTimeStamp

global hand

global imu_cb
global imu_bt

global mocap
global h0

global recording
global mov

global cameras

global framecount


currentTime = allTextTimeStamp{counter};

status = {};  % String to show which this timestamp belongs to
frameEachCam = {}; % display frame and time in cameras GUI
imuSel = [];
changeImu = 0;
changeAudio = 0;

% Play IMU
try
    if whatShow.imu_cb || whatShow.imu_bt
        % Figure out if user has chosen a different IMU to display
        imuDesc = hand.imuListDesc(hand.imuSel);
        newImuSel = get(hand.h_imu_list, 'Value');
        if hand.imuSel ~= newImuSel
            %state_stop(handles);
            hand.imuSel = newImuSel;
            imuDesc = hand.imuListDesc(hand.imuSel);
            changeImu = 1;
        end
        % Find kind of imu to plot ('imu_cb' | 'imu_bt')
        if whatShow.imu_cb
            imuSel = strmatch(imuDesc{1}, imu_cb.id, 'exact');
            if ~isempty(imuSel)
                typeimu = 'imu_cb';
            end
        end
        if whatShow.imu_bt && isempty(imuSel)
            imuSel = strmatch(imuDesc{1}, imu_bt.id, 'exact');
            if ~isempty(imuSel)
                typeimu = 'imu_bt';
            end
        end
        % If another IMU should be displayed update it
        if changeImu == 1
            showSensorsData(typeimu, imuSel);
        end
        if get(handles.checkbox_update_imu, 'Value') == get(handles.checkbox_update_imu, 'Max')
            sampleSensors = getContSampleIMU(currentTime, handles, typeimu);
            markAxesIMU(sampleSensors, typeimu, handles)
            tmSta = ['IMU ' imuDesc{1} ' :  ' num2str(sampleSensors)];
            status = [status tmSta];
        end
    end
catch ME
    state = state_paused (handles);
    msg = ['There was a problem updating IMU at time: ' currentTime];
    disp(ME.message); disp(msg); warndlg(msg, 'Error: Playing IMU');
end

% Play video
try
    if whatShow.Cams
        if get(handles.checkbox_update_cam, 'Value') == get(handles.checkbox_update_cam, 'Max')
            [imageName, frameEachCam, id] = getCurrentCamAndFrame(whatData, currentTime, handles);
            for k = 2:1:7
                if imageName{k}~=0 % contol from getCurrentCamAndFrame
                    try
                        im = imread(imageName{k});
                    catch ME
                        im = zeros(480,640);        
                    end
%                     if k~=3   % Don't show camera 2
                        imshow(im, 'Parent', each_handle_camera(k-1));
                        tmSta = ['Cam ' num2str(k-1) ' (' id{k-1}, ') : ' frameEachCam{k-1} ];
                        status = [status tmSta];
%                     end
                end
            end
        end
        if recording
            hCam = get(each_handle_camera(1),'Parent');
            F = getframe(hCam);
            imwrite(F.cdata,sprintf('videoframes/frame%06d.png',framecount));
            framecount = framecount + 1;
            %mov = addframe(mov,F);
        end
    end
catch ME
    state = state_paused (handles);
    msg = ['There was a problem updating camera at time: ' currentTime];
    warndlg(msg, 'Error: Playing CAMERAS');
    disp(msg)
    disp(ME.message)
end

try
    if whatShow.Audio
        audioDesc = hand.audioListDesc(hand.audioSel);
        % Figure out if user has chosen audio from a different mic to display
        newAudioSel = get(hand.h_audio_list, 'Value');
        if hand.audioSel ~= newAudioSel
            hand.audioSel = newAudioSel;
            audioDesc = hand.audioListDesc(hand.audioSel);
            showAudioData (hand.audioSel);
        end
        
        if get(handles.checkbox_update_audio, 'Value') == get(handles.checkbox_update_audio, 'Max')
            sampleAudio = getSampleAudio(currentTime, hand.audioSel, handles);
            markSampleAudio(sampleAudio, handles);
            tmSta = ['Audio ' audioDesc{1} ' :  ' num2str(sampleAudio)];
            status = [status  tmSta];
        end
    end
catch ME
    state = state_paused (handles);
    msg = ['There was a problem updating audio at time: ' currentTime];
    warndlg(msg, 'Error: Playing AUDIO');
    disp(msg)
    disp(ME.message)
end

try
    if whatShow.Mocap
        if get(handles.checkbox_update_mocap, 'Value') == get(handles.checkbox_update_mocap, 'Max')
            sampleMocap = getSampleMocap(currentTime, handles);
            h0 = showMotionFrame(mocap.wsDOF.cord, mocap.wsDOF.conn, sampleMocap, hand.h_mocap, hand.h_fig, 'h0', h0);
            tmSta =  ['MoCap :  ' num2str(sampleMocap)];
            status = [status tmSta];
        end
    end

catch ME
    state = state_paused (handles);
    msg= ['There was a problem updating MoCap at time: ' currentTime];
    warndlg(msg, 'Error: Playing MOCAP');
    disp(msg)
    disp(ME.message)
end

try
    if whatShow.rfid
        if get(handles.checkbox_update_mocap, 'Value') == get(handles.checkbox_update_mocap, 'Max')
            sampleRFID = getSampleRFID(currentTime, handles);
            tagRFID = markSampleRFID(sampleRFID, hand);
            tmSta = ['RFID :  ' tagRFID];
            status = [status  tmSta];
        end
    end
catch ME
    state = state_paused (handles);
    msg = ['There was a problem updating RFID at time: ' currentTime];
    warndlg(msg, 'Error: Playing RFID');
    disp(msg)
    disp(ME.message)
end

try
    if whatShow.ewatch
        if get(handles.checkbox_update_ewatch, 'Value') == get(handles.checkbox_update_ewatch, 'Max')
            %
            %
            %
            neweWatchSel = get(hand.h_ewatch_list, 'Value');
            if hand.ewatchSel ~= neweWatchSel
                hand.ewatchSel = neweWatchSel;
                showeWatchData(handles, neweWatchSel);
            end
            %
            % 
            sampeWatch = getSampeWatch(currentTime, handles);
            markSampeWatch(sampeWatch, handles);
            tmSta = ['eWatch :  ' num2str(sampeWatch)];
            status = [status  tmSta];
        end
    end
catch ME
    state = state_paused (handles);
    msg = ['There was a problem updating eWatch at time: ' currentTime];
    warndlg(msg, 'Error: Playing eWatch');
    disp(msg)
    disp(ME.message)
end

showInfo(handles, status, counter, frameEachCam, hand);
