% Synchronize system time in timestamps those with same trigger
function sysTime = preSyncCameras (cPath)
    
    dataDir = dir(cPath);

    i=1;

    while (isempty(strfind(dataDir(i).name, 'Video')) && isempty(strfind(dataDir(i).name, 'video')) || ~dataDir(i).isdir) && i < size({dataDir.name},2) 
        i=i+1; 
    end
    if ~(isempty(strfind(dataDir(i).name, 'Video')) && isempty(strfind(dataDir(i).name, 'video')) || ~dataDir(i).isdir)
        pathFile = strcat(cPath, filesep ,dataDir(i).name);
    else
        pathFile = strcat(cPath);
    end

    sTimeNames = dir(pathFile);

    % store each camera's timestamp
    k =1;
    for i=1:length(sTimeNames)
        if length(sTimeNames(i).name)>8 ...
                && strcmp(sTimeNames(i).name(length(sTimeNames(i).name)-8:length(sTimeNames(i).name)), '-time.txt') ...
                && isempty(findstr(sTimeNames(i).name, 'Onboard'))
            [frames{k} sysTime{k} ] = textread([pathFile filesep sTimeNames(i).name], '%s%*s%*s%*s%s');
            numFrames{k} = zeros(size(frames{k}));
            lostFrames{k} = [];
            for j=1:size(frames{k},1)
                [token, remain] =strtok(frames{k}(j), ':');
                numFrames{k}(j) = str2double(remain{1}(2:end));
                if j~=1 
                    lost = numFrames{k}(j)-numFrames{k}(j-1);
                    if lost>1
                        for l = lost-1:-1:1
                            lostFrames{k} = [lostFrames{k} (numFrames{k}(j)-l)];
                        end
                    end
                end
            end
            fileName{k} = [pathFile filesep sTimeNames(i).name];
            k = k+1;
        end
    end
    k = k-1;

    firstSysTime = cell(1,k);
    for i=1:k
        firstSysTime{i} = sysTime{i}{1};
    end

    [posMax, max1stSysTime] = compTimes(firstSysTime);


    for i=1:k

        % Get frame period
        [framePeriod, frameRate] = getPeriod(sysTime{i}{2}, sysTime{i}{1});


        % Find the closest time to max1stSysTime
        difSecs = abs(timestamp2sec(sysTime{i}) - timestamp2sec(max1stSysTime));
        a = find(difSecs == min(difSecs),1);
        sysTime{i}{a} = max1stSysTime;

        % Complete to the end
        % Change systime adding frame period to the latter timestamp
        for j=a(1):size(sysTime{i}, 1) -1
            sysTime{i}{j +1} = addSysTime(framePeriod, sysTime{i}{j});
        end

        % Complete to the beginning
        % Change systime adding frame period to the later timestamp
        if a(1) > 1
            for j=a(1): -1:2
                sysTime{i}{j -1} = addSysTime(-framePeriod, sysTime{i}{j});
            end
        end

        save2file(fileName{i}, sysTime{i}, numFrames{i});
        fprintf('Iteration : %d, file %s finished!\n', i, fileName{i});    

end




function [posMax, max1stSysTime] = compTimes(firstSysTime)

hh = zeros(1, size(firstSysTime,2));
mm = zeros(1, size(firstSysTime,2));
ss = zeros(1, size(firstSysTime,2));
uu = zeros(1, size(firstSysTime,2));

for i=1:size(firstSysTime,2)
    hh(i) = str2double(firstSysTime{i}(1:2));
    mm(i) = str2double(firstSysTime{i}(4:5));
    ss(i) = str2double(firstSysTime{i}(7:8));
    uu(i) = str2double(firstSysTime{i}(10:16));
end


maxhh = find(hh == max(hh),1);
mm(find( hh ~= hh(maxhh))) = 0; 
maxmm = find(mm == max(mm),1);
ss([find(mm~=mm(maxmm)) find(mm==0)]) = 0;
maxss = find(ss == max(ss),1);
uu([find(ss~=ss(maxss)) find(ss==0)]) = 0;
maxuu = find(uu == max(uu),1);

posMax = maxuu;
max1stSysTime = firstSysTime{posMax};



function [framePeriod, frameRate] = getPeriod(sysTimeII, sysTimeI)
% framePeriod in 1/10*microseconds

hhII = str2double(sysTimeII(1:2));
mmII = str2double(sysTimeII(4:5));
ssII = str2double(sysTimeII(7:8));
uuII = str2double(sysTimeII(10:16));

hhI = str2double(sysTimeI(1:2));
mmI = str2double(sysTimeI(4:5));
ssI = str2double(sysTimeI(7:8));
uuI = str2double(sysTimeI(10:16));


uuII = uuII + 10^7*ssII + 60*10^7*mmII + 60*60*10^7*hhII;
uuI = uuI + 10^7*ssI + 60*10^7*mmI + 60*60*10^7*hhI;

framePeriod = (uuII - uuI)/10^7;
frameRate = round(1/framePeriod);

frameRateTemplate = [30, 60];

[val, in] = min (abs(frameRateTemplate- frameRate));

frameRate = frameRateTemplate(in);

%framePeriod = floor(1/frameRate*10^7)/10^7;

if frameRate == 30
    framePeriod = 0.033332;
else
    framePeriod = 0.016666;
end


function nextTime = addSysTime(framePeriod, sysTime)

hhC = str2double(sysTime(1:2));
mmC = str2double(sysTime(4:5));
ssC = str2double(sysTime(7:8));
uuC = str2double(sysTime(10:16));

uu = framePeriod*10^7 + uuC + ssC*10^7 + mmC*60*10^7 + hhC*60*60*10^7;

ss = floor( uu/10^7 );

uuN = (uu/10^7 - floor(uu/10^7)) *10^7;
uuN = round(uuN);
ssN = mod(ss, 60);
mm = floor(ss/60);
mmN = mod(mm, 60);
hhN = floor(mm/60);

uuStr = num2str(uuN, '%d');
if length(uuStr) < 7
    trunc = 7 - length(uuStr);
    for ii = 6-trunc+1 : 6
        tmp = strcat('0', uuStr(length(uuStr)- (6-trunc) : length(uuStr)));
        uuStr = strcat(uuStr(1: length(uuStr)-(6-trunc+1) ), tmp);
    end
end

ssStr = num2str(ssN, '%d');
if length(ssStr) < 2
    ssStr = ['0' ssStr];
end

mmStr = num2str(mmN, '%d');
if length(mmStr) < 2
	mmStr = ['0' mmStr];
end

hhStr = num2str(hhN, '%d');
if length(hhStr) < 2
	hhStr = ['0' hhStr];
end

nextTime = [ hhStr '_' mmStr '_' ssStr '_' uuStr];


function save2file(fileName, sysTime, numFrames)

fileName = [fileName(1:length(fileName)-4) '-presynch.txt'];
fid = fopen(fileName,'w');
for i=1:size(sysTime, 1)
    fprintf(fid,'Frame:%d Fwt:----.---- EPOCH: -- %s\n', ...
        numFrames(i), sysTime{i});
end
fclose(fid);
