function RFIDfileExpanded = preSyncRFID(RFIDfile)

    fid = fopen(RFIDfile);
    strRFIDData = textscan(fid, '%s %s %s');
    fclose(fid);
    
    [pathstr, name, ext, versn] = fileparts(RFIDfile);
    RFIDfileExpanded = [pathstr, filesep, name, '-presync',ext];
    
    for i = 1 : size(strRFIDData{2},1)
        strRFIDData{2}{i}=strrep(strRFIDData{2}{i},'.','_');
        strRFIDData{2}{i}=strrep(strRFIDData{2}{i},':','_');
        strRFIDData{2}{i}=strcat(strRFIDData{2}{i},'0');
    end
    
    timestamp=strRFIDData{2}{1};
    firstsec=timestamp2sec(timestamp);
    lastsec=timestamp2sec(strRFIDData{2}{size(strRFIDData{1},1)});
    lastFrame=(round(lastsec-firstsec)+1)*5;
    
    disp(['Creating file: ' RFIDfileExpanded]);
    fid = fopen(RFIDfileExpanded, 'w');
    Pos=1;
    for i=1:lastFrame
        [RFIDTag,Pos]=getRFIDTag(strRFIDData,i,Pos,timestamp);
        fprintf(fid,'%s %s %s\n',strRFIDData{1}{1},timestamp,RFIDTag);
        timestamp=addSysTime(1/10,timestamp);
    end
    
    %timeString = strDataMocap{size(strDataMocap, 2)};
    %[samplePeriod, sampleFreq] = getPeriodSample(strDataMocap{2}{2}, strDataMocap{2}{1});
    %for i = 1 : size(strDataMocap{1},1)
    % 	newTimeStr = addSysTime(off*samplePeriod, timeString{i});
    % 	fprintf(fid,'%s %s\n',strDataMocap{1}{i},newTimeStr);                
    %end
    
    fclose(fid);
    
function [RFIDTag, iold] = getRFIDTag(strRFIDData,inew,iold,timestamp)
    newsec=timestamp2sec(timestamp);
    oldsec=timestamp2sec(strRFIDData{2}{iold});
    dif=newsec-oldsec;
    
    nextoldsec=timestamp2sec(strRFIDData{2}{iold+1});
    newdif=newsec-nextoldsec;
    
    if newdif<0
       newdif=newdif*-1; 
    end
    if newdif<dif && iold+1<size(strRFIDData{2},1)
        iold=iold+1;
    end
    
    RFIDTag=strRFIDData{3}{iold};


function [samplePeriod, sampleFreq] = getPeriodSample(sysTimeII, sysTimeI)
% framePeriod in 1/10*microseconds

hhII = str2double(sysTimeII(1:2));
mmII = str2double(sysTimeII(4:5));
ssII = str2double(sysTimeII(7:8));
uuII = str2double(sysTimeII(10:16));

hhI = str2double(sysTimeI(1:2));
mmI = str2double(sysTimeI(4:5));
ssI = str2double(sysTimeI(7:8));
uuI = str2double(sysTimeI(10:16));


uuII = uuII + 10^7*ssII + 60*10^7*mmII + 60*60*10^7*hhII;
uuI = uuI + 10^7*ssI + 60*10^7*mmI + 60*60*10^7*hhI;

samplePeriod = (uuII - uuI)/10^7;
sampleFreq = round(1/samplePeriod);



function nextTime = addSysTime(framePeriod, sysTime)

hhC = str2double(sysTime(1:2));
mmC = str2double(sysTime(4:5));
ssC = str2double(sysTime(7:8));
uuC = str2double(sysTime(10:16));

uu = framePeriod*10^7 + uuC + ssC*10^7 + mmC*60*10^7 + hhC*60*60*10^7;

ss = floor( uu/10^7 );

uuN = (uu/10^7 - floor(uu/10^7)) *10^7;
uuN = round(uuN);
ssN = mod(ss, 60);
mm = floor(ss/60);
mmN = mod(mm, 60);
hhN = floor(mm/60);

uuStr = num2str(uuN, '%d');
if length(uuStr) < 7
    trunc = 7 - length(uuStr);
    for ii = 6-trunc+1 : 6
        tmp = strcat('0', uuStr(length(uuStr)- (6-trunc) : length(uuStr)));
        uuStr = strcat(uuStr(1: length(uuStr)-(6-trunc+1) ), tmp);
    end
end

ssStr = num2str(ssN, '%d');
if length(ssStr) < 2
    ssStr = ['0' ssStr];
end

mmStr = num2str(mmN, '%d');
if length(mmStr) < 2
	mmStr = ['0' mmStr];
end

hhStr = num2str(hhN, '%d');
if length(hhStr) < 2
	hhStr = ['0' hhStr];
end

nextTime = [ hhStr '_' mmStr '_' ssStr '_' uuStr];

function [framePeriod, frameRate] = getPeriod(sysTimeII, sysTimeI)
% framePeriod in 1/10*microseconds

hhII = str2double(sysTimeII(1:2));
mmII = str2double(sysTimeII(4:5));
ssII = str2double(sysTimeII(7:8));
uuII = str2double(sysTimeII(10:16));

hhI = str2double(sysTimeI(1:2));
mmI = str2double(sysTimeI(4:5));
ssI = str2double(sysTimeI(7:8));
uuI = str2double(sysTimeI(10:16));


uuII = uuII + 10^7*ssII + 60*10^7*mmII + 60*60*10^7*hhII;
uuI = uuI + 10^7*ssI + 60*10^7*mmI + 60*60*10^7*hhI;

framePeriod = (uuII - uuI)/10^7;
frameRate = round(1/framePeriod);

frameRateTemplate = [30, 60];

[val, in] = min (abs(frameRateTemplate- frameRate));

frameRate = frameRateTemplate(in);

%framePeriod = floor(1/frameRate*10^7)/10^7;

if frameRate == 30
    framePeriod = 0.033332;
else
    framePeriod = 0.016666;
end


    