% Synchronize system time in timestamps those with same trigger
function mocapTimeGenerator(path)

    offsetFile = 'offsets.txt';
    
    global lastFrame;
    mocapPath=[path,'mocap',filesep];
    dataDir = dir(mocapPath);
    amcname = [];
    n_temp = length(dataDir);
    for i=1:n_temp
        if ~isempty(regexpi(dataDir(i).name, '\.amc')) && ~isDir(dataDir(i).name)
            amcname = dataDir(i).name;
        end
    end;
    if isempty(amcname)
        msg = ['Problem finding AMC file.'];
        warndlg(msg, 'Error: Reading AMC file');
        
    else
        
        %Get last mocap frame number
        amcfile=[mocapPath,amcname];
        fid=fopen(amcfile,'r');
        fseek(fid,-2100,'eof');
        
        temp=fgetl(fid);
        while ~feof(fid)
            frame=str2num(temp);
            if frame>2
               lastFrame=frame;
            end
            temp=fgetl(fid);
        end
        fclose(fid);
        
        %find video timestamp files
        i=1;
        dataDir = dir(path);        
        while (isempty(strfind(dataDir(i).name, 'Video')) && isempty(strfind(dataDir(i).name, 'video')) || ~dataDir(i).isdir) && i < size({dataDir.name},2)
            i=i+1; 
        end
        if ~(isempty(strfind(dataDir(i).name, 'Video')) && isempty(strfind(dataDir(i).name, 'video')) || ~dataDir(i).isdir)
            videoPath = strcat(path, filesep, dataDir(i).name, filesep);
        else
            videoPath = path;
        end
               
        temp = dir([videoPath,'*-time-synch.txt']);
        n_temp = length(temp);
        if n_temp==0
            temp = dir([videoPath,'-time-presynch.txt']);
            n_temp = length(temp);
        end
        if n_temp==0
            msg = ['No video time stamps found.'];
            warndlg(msg, 'Error: Reading video time stamps'); 
        else
            n = 1;
            for i=1:n_temp
                if strfind(temp(n).name,'STime7151020')
                    videoTimeStamp=temp(n).name;
                end
                stime{n} = temp(n).name;
                n = n+1;
            end;
            
            if isempty(videoTimeStamp)
                videoTimeStamp=stime{n};
            end
            
            videoTimeStamp=[videoPath,videoTimeStamp];
            fid=fopen(videoTimeStamp,'r');
            
            temp=fgetl(fid);
            index=strfind(temp,' -- ');
            parts=strsplit(' -- ',temp,'omit')
            
            timestamp=parts{2};
            
            fclose(fid)
            fprintf('Generating mocapTime.txt...\n');
            %create mocap timestamp
            fid=fopen([mocapPath,'mocapTime.txt'],'w');
            for i=1:lastFrame
               fprintf(fid,'Frame:%d %s\n',i,timestamp);
               timestamp=addSysTime(1/120,timestamp);
            end
            fclose(fid);
            fprintf('mocapTime.txt succefuly generated!\n');
        end
    end
    
      
function parts = strsplit(splitstr, str, option)
%STRSPLIT Split string into pieces.
%
%   STRSPLIT(SPLITSTR, STR, OPTION) splits the string STR at every occurrence
%   of SPLITSTR and returns the result as a cell array of strings.  By default,
%   SPLITSTR is not included in the output.
%
%   STRSPLIT(SPLITSTR, STR, OPTION) can be used to control how SPLITSTR is
%   included in the output.  If OPTION is 'include', SPLITSTR will be included
%   as a separate string.  If OPTION is 'append', SPLITSTR will be appended to
%   each output string, as if the input string was split at the position right
%   after the occurrence SPLITSTR.  If OPTION is 'omit', SPLITSTR will not be
%   included in the output.

%   Author:      Peter J. Acklam
%   Time-stamp:  2004-09-22 08:48:01 +0200
%   E-mail:      pjacklam@online.no
%   URL:         http://home.online.no/~pjacklam

   nargsin = nargin;
   error(nargchk(2, 3, nargsin));
   if nargsin < 3
      option = 'omit';
   else
      option = lower(option);
   end

   splitlen = length(splitstr);
   parts = {};

   while 1

      k = strfind(str, splitstr);
      if isempty(k)
         parts{end+1} = str;
         break
      end

      switch option
         case 'include'
            parts(end+1:end+2) = {str(1:k(1)-1), splitstr};
         case 'append'
            parts{end+1} = str(1 : k(1)+splitlen-1);
         case 'omit'
            parts{end+1} = str(1 : k(1)-1);
         otherwise
            error(['Invalid option string -- ', option]);
      end


      str = str(k(1)+splitlen : end);

   end

    

function [samplePeriod, sampleFreq] = getPeriodSample(sysTimeII, sysTimeI)
% framePeriod in 1/10*microseconds

hhII = str2double(sysTimeII(1:2));
mmII = str2double(sysTimeII(4:5));
ssII = str2double(sysTimeII(7:8));
uuII = str2double(sysTimeII(10:16));

hhI = str2double(sysTimeI(1:2));
mmI = str2double(sysTimeI(4:5));
ssI = str2double(sysTimeI(7:8));
uuI = str2double(sysTimeI(10:16));


uuII = uuII + 10^7*ssII + 60*10^7*mmII + 60*60*10^7*hhII;
uuI = uuI + 10^7*ssI + 60*10^7*mmI + 60*60*10^7*hhI;

samplePeriod = (uuII - uuI)/10^7;
sampleFreq = round(1/samplePeriod);


function nextTime = addSysTime(framePeriod, sysTime)

hhC = str2double(sysTime(1:2));
mmC = str2double(sysTime(4:5));
ssC = str2double(sysTime(7:8));
uuC = str2double(sysTime(10:16));

uu = framePeriod*10^7 + uuC + ssC*10^7 + mmC*60*10^7 + hhC*60*60*10^7;

ss = floor( uu/10^7 );

uuN = (uu/10^7 - floor(uu/10^7)) *10^7;
uuN = round(uuN);
ssN = mod(ss, 60);
mm = floor(ss/60);
mmN = mod(mm, 60);
hhN = floor(mm/60);

uuStr = num2str(uuN, '%d');
if length(uuStr) < 7
    trunc = 7 - length(uuStr);
    for ii = 6-trunc+1 : 6
        tmp = strcat('0', uuStr(length(uuStr)- (6-trunc) : length(uuStr)));
        uuStr = strcat(uuStr(1: length(uuStr)-(6-trunc+1) ), tmp);
    end
end

ssStr = num2str(ssN, '%d');
if length(ssStr) < 2
    ssStr = ['0' ssStr];
end

mmStr = num2str(mmN, '%d');
if length(mmStr) < 2
	mmStr = ['0' mmStr];
end

hhStr = num2str(hhN, '%d');
if length(hhStr) < 2
	hhStr = ['0' hhStr];
end

nextTime = [ hhStr '_' mmStr '_' ssStr '_' uuStr];

function [framePeriod, frameRate] = getPeriod(sysTimeII, sysTimeI)
% framePeriod in 1/10*microseconds

hhII = str2double(sysTimeII(1:2));
mmII = str2double(sysTimeII(4:5));
ssII = str2double(sysTimeII(7:8));
uuII = str2double(sysTimeII(10:16));

hhI = str2double(sysTimeI(1:2));
mmI = str2double(sysTimeI(4:5));
ssI = str2double(sysTimeI(7:8));
uuI = str2double(sysTimeI(10:16));


uuII = uuII + 10^7*ssII + 60*10^7*mmII + 60*60*10^7*hhII;
uuI = uuI + 10^7*ssI + 60*10^7*mmI + 60*60*10^7*hhI;

framePeriod = (uuII - uuI)/10^7;
frameRate = round(1/framePeriod);

frameRateTemplate = [30, 60];

[val, in] = min (abs(frameRateTemplate- frameRate));

frameRate = frameRateTemplate(in);

%framePeriod = floor(1/frameRate*10^7)/10^7;

if frameRate == 30
    framePeriod = 0.033332;
else
    framePeriod = 0.016666;
end

