function value = parseField(option, name, default)
% Fetch the field of the option with the specified name.
% If the field does not exist, use the default value instead.
% Input
%   option  -   struct or string cell array
%   name    -   name of the field
%   default -   default value of the field
% Output
%   value   -   the value of the field for the given struct

if iscell(option)
    if isempty(option)
        option = [];
    elseif length(option) == 1
        option = option{1};
    else
        option = cell2option(option);
    end
end

if isfield(option, name)
    value = option.(name);
else
    value = default;
end