function h = showMotionFrame(cord, cone, iF, h_mocap, h_fig, varargin)
% Show one frame of the given motion.
% Input
%   cord            -   3-D coordinates of the joints, nF x nJ x 3 matrix
%   cone            -   joints that bone connect, nB x 2 matrix
%   skel            -   skeleton
%   iF              -   frame position
%   varargin
%        .video     -   this frame belongs to a video, {'y'} | 'n'
%        .h0        -   initial body connection handle, using in producing a video, {[]}

% parse option
isFirst = iF == 1;
isVideo = isYes(parseField(varargin, 'video', 'y'));
h0 = parseField(varargin, 'h0', []); 

% line's width
lineWidth = 2;
lineStyle = '-';
color = 'b';

% coordinates
% joints
xJ = cord(iF, :, 1); yJ = cord(iF, :, 3); zJ = cord(iF, :, 2);

% connection
xB = [cord(iF, cone(:, 1), 1); cord(iF, cone(:, 2), 1)];
yB = [cord(iF, cone(:, 1), 3); cord(iF, cone(:, 2), 3)];
zB = [cord(iF, cone(:, 1), 2); cord(iF, cone(:, 2), 2)];

% axis boundary
lim = zeros(3, 2);
X = cord(:, :, 1); Y = cord(:, :, 3); Z = cord(:, :, 2);
lim(1, :) = [min(X(:)), max(X(:))];
lim(2, :) = [min(Y(:)), max(Y(:))];
lim(3, :) = [min(Z(:)), max(Z(:))];
    
if isFirst && isempty(h0)
    % plot a phantom point
    set(h_fig,'CurrentAxes',h_mocap);
    set(h_mocap, 'xlim', lim(1, :), 'ylim', lim(2, :), 'zlim', lim(3, :));
    plot3(xJ(1), yJ(1), zJ(1), '.', 'MarkerSize', 0.1);
    hold on; axis ij; axis equal; %grid on; 
end

% connection of joints
nB = size(xB, 2);
hConn = cell(1, nB);
for i = 1 : nB
    if ~isVideo || isempty(h0) % redraw the body for non-video or the first frame of video
        set(h_fig,'CurrentAxes',h_mocap);
        hConn{i} = line(xB(:, i), yB(:, i), zB(:, i), 'Color', color, 'LineWidth', lineWidth, 'LineStyle', lineStyle);
    else % change the coordinates
        hConn{i} = h0.hConn{i};
        set(h_fig,'CurrentAxes',h_mocap);
        set(hConn{i}, 'XData', xB(:, i), 'YData', yB(:, i), 'ZData', zB(:, i));
    end
end
if isVideo, h.hConn = hConn; end
