function rot = ang2matrix(ang, varargin)
% Convert euler angles into a rotation matrix.
%
% Input
%   ange      -  angle vector that contains x y z components
%   varargin  -  function options
%     unit    -  the unit of ang, if is degree, need be converted. {'deg'} | 'rad'
%                'deg' - degree, 'rad' - radian
%     order   -  the rotating order {'zyx'};
%
% Output
%   rot       -  rotation matrix
%
% History
%   create  -  Feng Zhou, 03-17-2009
%   modify  -  Feng Zhou, 03-17-2009

% function option
unit = ps(varargin, 'unit', 'deg');
order = ps(varargin, 'order', 'zyx');

if strcmp(unit, 'deg')
    ang = deg2rad(ang);
end

c1 = cos(ang(1)); % The x angle
c2 = cos(ang(2)); % The y angle
c3 = cos(ang(3)); % the z angle
s1 = sin(ang(1));
s2 = sin(ang(2));
s3 = sin(ang(3));

rot = eye(3);
for i = 1 : length(order)
    if order(i) == 'x'
        tmp = [1   0   0; ...
               0  c1  s1; ...
               0 -s1  c1];
         
    elseif order(i) == 'y'
        tmp = [c2  0 -s2; ...
                0  1   0; ...
               s2  0  c2];
           
    elseif order(i) == 'z'
        tmp = [c3  s3  0; ...
              -s3  c3  0; ...
                0   0  1];
    else
        error('unknown order');
    end
    
    rot = tmp * rot;
end
