function [skel, channels] = dof2skel(DOF, joint, skel)
% Parse the structure of DOFs.
%
% Input
%   DOF      -  d x n matrix, d = #dof, n = #frames
%   joint
%   skel
%
% Output
%   skel
%   channels
%
% History
%   create  -  Feng Zhou, 04-26-2008
%   modify  -  Feng Zhou, 04-26-2009

fprintf('dof -> skel...');

name = joint.name; nJ = length(name); dim = joint.dim;
loc = zeros(1, nJ); loc(1) = 1;
for i = 2 : nJ
    loc(i) = loc(i - 1) + dim(i - 1);
end

n = size(DOF, 2);

for j = 1 : nJ
    ind = strloc(name{j}, skel.tree, 'name');

    for i = 1 : n
        for k = 1 : dim(j)
            bone{ind}{i}(k) = DOF(loc(j) + k - 1, i);
        end
    end
end

numFrames = n;
numChannels = 0;
for i = 1 : length(skel.tree)
    numChannels = numChannels + length(skel.tree(i).channels);
end
channels = zeros(numFrames, numChannels);

endVal = 0;
for i = 1 : length(skel.tree)
  if ~isempty(skel.tree(i).channels)
    startVal = endVal + 1;
    endVal = endVal + length(skel.tree(i).channels);
    channels(:, startVal:endVal)= reshape([bone{i}{:}], ...
                                          length(skel.tree(i).channels), numFrames)';
  end
  [skel.tree(i).rotInd, skel.tree(i).posInd] = ...
      resolveIndices(skel.tree(i).channels, startVal);
end

channels = smoothAngleChannels(channels, skel);

fprintf('done\n');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [rotInd, posInd] = resolveIndices(channels, startVal)
% RESOLVEINDICES Get indices from the channels.

baseChannel = startVal - 1;
rotInd = zeros(1, 3);
posInd = zeros(1, 3);
for i = 1:length(channels)
  switch channels{i}
   case 'Xrotation'
    rotInd(1, 1) = baseChannel + i;
   case 'Yrotation'
    rotInd(1, 2) = baseChannel + i;
   case 'Zrotation'
    rotInd(1, 3) = baseChannel + i;
   case 'Xposition'
    posInd(1, 1) = baseChannel + i;
   case 'Yposition'
    posInd(1, 2) = baseChannel + i;
   case 'Zposition'
    posInd(1, 3) = baseChannel + i;
  end        
end