function [DOF, joint] = dofFilter(DOF0, joint0, paraF)
% Filter the unnecessary DOFs according to the specific
% method sepecified by paraF.filter.
%
% Input
%   DOF0      -  old DOF matrix, dim x nF0
%   joint0    -  old joints that are related to DOF0
%     dim     -  #DOFs of each joint
%     name    -  name of each joint
%   paraF  
%     filter  -  filtering method, {'barbic'} | 'all' | 'arm' | 'arm+leg+torso'
%                'barbic'  -  14 joints, See: http://graphics.cs.cmu.edu/projects/segmentation
%                'all'     -  keep all
%                'arm'     -  right arm
%                'arm+leg+torso' - kitchen
%
% Output
%   DOF       -  new DOF matrix, (nJ x 3) x nF
%   joint     -  new joints
%
% History
%   create    -  Feng Zhou, 12-29-2008
%   modify    -  Feng Zhou, 12-29-2008

% parse type
type = ps(paraF, 'filter', 'barbic');

if strcmpi(type, 'barbic')
    used = {'lowerback', ...
            'upperback', ...
            'thorax', ...
            'lowerneck', ...
            'upperneck', ...
            'head', ...
            'rhumerus', ...
            'rradius', ...
            'lhumerus', ...
            'lradius', ...
            'rfemur', ...
            'rtibia', ...
            'lfemur', ...
            'ltibia'};

elseif strcmpi(type, 'arm+leg+torso')
    used = {'lowerback', ...
            'lhumerus', ...
            'lradius', ...
            'lfemur', ...
            'rhumerus', ...
            'rfemur', ...
            'rradius'};
        
elseif strcmpi(type, 'arm')
    used = {'rhumerus', ...
            'rradius'};%, ...
            % 'lhumerus', 'lradius'
            %'rhand', 'lhand', ...};
        
elseif strcmpi(type, 'all')
    used = joint0.name;
    
else
    error(['unknown type: ' type]);
end

% starting row of joint in the input DOF0
dim0 = joint0.dim;
nJ0 = length(dim0); n = size(DOF0, 2);
head0 = ones(1, nJ0);
for i = 2 : nJ0
    head0(i) = head0(i - 1) + dim0(i - 1);
end

% available used joints
name0 = joint0.name;
ind = zeros(size(name0));
for i = 1 : length(name0);
    for j = 1 : length(used)
        if strcmpi(name0{i}, used{j})
            ind(i) = 1;
            break;
        end
    end
end
sub = find(ind); nJ = length(sub);

% filtering
DOF = zeros(nJ * 3, n);
name = cell(1, nJ);
for i = 1 : nJ
    p = sub(i);
    name{i} = name0{p};
    d = dim0(p);
    DOF((i - 1) * 3 + 1 : (i - 1) * 3 + d, :) = DOF0(head0(p) : head0(p) + d - 1, :);
end

joint.name = name;
joint.dim = ones(1, nJ) * 3;
