function DOF = dofJoin(DOFs)
% Concatenate the DOF matrices.
% The consecutive sequences will be concatenated at the ends.
%
% Input
%   DOFs    -  the old DOF list, 1 x n (cell)
%
% Output
%   DOF     -  the new DOF, dim x nF
%
% History
%   create  -  Feng Zhou, 12-29-2008
%   modify  -  Feng Zhou, 12-29-2008


n = length(DOFs);
DOF = DOFs{1};

for i = 2 : n
    DOF = dofJoinTwo(DOF, DOFs{i});
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function DOF = dofJoinTwo(DOF1, DOF2)
% Concatenate the DOF matrics.
%
% Input
%   DOF1  -  the 1st dof, dim x nF1
%   DOF2  -  the 2nd dof, dim x nF2
%
% Output
%   DOF   -  the result dof, dim x (nF1 + nF2)
%
% History
%   create  -  Feng Zhou, 12-29-2008
%   modify  -  Feng Zhou, 12-29-2008

X1 = DOF1([1 3], :);
X2 = DOF2([1 3], :);

% join the end
n = size(X2, 2);
X2 = X2 - repmat(X2(:, 1), 1, n) + repmat(X1(:, end), 1, n);

DOF2([1 3], :) = X2;
DOF = [DOF1, DOF2];