function [DOF, angV, angP] = dofPathNew(DOF0, st, varargin)
% Change the path shape of the given motion correpsonding to certain curve type.
% Input
%   DOF0     -  orginal dof
%   st       -  breaking point for multi-dof
%   varargin
%     type   -  curve function, {'l'} | 's' | 'o', 'l' -> line, 's' -> S type, 'o' - circle
% Output
%   DOF      -  new dof
%   angV     -  angle value for each joint
%   angP     -  relative position 

fprintf('new path...');

% original path
X0 = DOF0([1 3], :);
n = size(X0, 2);
[vels, angs] = direX(X0);
pos = smoothP(vels, st);
[len0, len0s] = lenX(X0);

% curve function
type = ps(varargin, 'type', 'l');
Xc = genCurve('type', type, 'n', 20000);
nc = size(Xc, 2);
lenc = lenX(Xc);

% adjust the length of the curve to fit the motion
Xc = expX(Xc, len0 / lenc);
[lenc, lencs] = lenX(Xc);
[velcs, angcs] = direX(Xc);

% move on the adjusted curve
if isempty(st), st = [1, n + 1]; end
X = X0; j = 1; dire = zeros(1, n);
for i = 2 : n
    isDone = false;
    while ~isDone || (j <= nc && len0s(i) > lencs(j))
        j = j + 1;
        isDone = true;
    end
    j = min(j, nc);
    X(:, i) = Xc(:, j);
    dire(i) = angcs(j);
end
X(:, 1) = Xc(:, 1); dire(:, 1) = angcs(1);

% direction
blockP = frame2block(1 : n, st);
[angV, angP] = zeross(1, n);
for i = 1 : n
    center = pos(blockP(i));
    dire0 = angs(center);
    dire1 = dire(i);
    
    angV(i) = dire1 - dire0;
    angP(i) = center;
end
 
% update
DOF = DOF0;
DOF(1, :) = X(1, :);
DOF(3, :) = X(2, :);

fprintf('done\n');
