function [cord, cone, angys] = parseCoordinate(skel, channels, angV, angP)
% Parse the skeleton and joints to determine the coordinates of each joint and the bones that attach them.
% Input
%   skel      -  skeleton components
%   channels  -  joint components
%     angV    -  the angles, {[]}
%     angP    -  the angles, {[]}
% Output
%   cord      -  3-D coordinates of each joints, nF x nJ x 3 matrix
%   cone      -  the two joints which is joined by the bone, nB x 2 matrix

fprintf('parse coordinate...');

nF = size(channels, 1);
nJ = length(skel.tree);
cord = zeros(nF, nJ, 3);

% y angles of root
angys = zeros(1, nF);
for i = 1 : nF
    angys(i) = rootAngY(skel, channels(i, :));
end

for i = 1 : nF
    ang = 0;
    if nargin > 2
        ang = -angys(i) + angys(angP(i)) - angV(i);
    end
    
    cord(i, :, :) = skel2xyz(skel, channels(i, :), ang);
end

% connection matrix
connect = zeros(nJ);
for i = 1 : nJ
    for j = 1 : length(skel.tree(i).children)    
        connect(i, skel.tree(i).children(j)) = 1;
    end
end

indices = find(connect);
nB = size(indices, 1);
cone = zeros(nB, 2);
[cone(:, 1), cone(:, 2)] = ind2sub(size(connect), indices);

fprintf('done\n');

%*****************************%
function angy = rootAngY(skel, channels)
% Parse the angles of root

rotVal = skel.tree(1).orientation;
for i = 1 : length(skel.tree(1).rotInd)
    rind = skel.tree(1).rotInd(i);
    if rind
        rotVal(i) = rotVal(i) + channels(rind);
    end
end

% root rotation
xyzStruct(1).rot = ang2matrix(rotVal, 'order', skel.tree(1).axisOrder);

% original rotation
ang0 = SpinCalc('DCMtoEA132', xyzStruct(1).rot, eps, 0);
if ang0 > 180
    ang0 = 360 - ang0;
end
angy = deg2rad(ang0(end));
