function cord = xyzGapNew(cord0, skel, amp)
% Adjust the gap between frames.
% Input
%   cord0  -  original coordinates
%   skel   -  skel structure
%   amp    -  amplifying rate
% Output
%   cord   -  new coordinates

nF = size(cord0, 1); nJ = size(cord0, 2);
rootJ = strloc('root', skel.tree, 'name');

% average bones' length
dx = cord0(1, 1, :) - cord0(1, 2, :);
len = sqrt(sum(dx(:) .^ 2));
if len < eps
    dx = cord0(1, 1, :) - cord0(1, 3, :);
    len = sqrt(sum(dx(:) .^ 2));
end

% adjust
cord = cord0;
for iF = 2 : nF
    DX0 = cord0(iF, rootJ, :) - cord0(iF - 1, rootJ, :);
    DX = DX0 * amp; DX(2) = 0;
    len0 = sqrt(sum(DX(:) .^ 2));
    DX = DX / len0 * len * amp;
    
    cord(iF, rootJ, :) = cord(iF - 1, rootJ, :) + DX;
    cord(iF, rootJ, 2) = cord0(iF, rootJ, 2);
    for iJ = 1 : nJ
        DX0 = cord0(iF, iJ, :) - cord0(iF, rootJ, :);
        cord(iF, iJ, :) = cord(iF, rootJ, :) + DX0;            
    end
end

% move the corner to [0 0 0]
X = cord(:, :, 1); Y = cord(:, :, 2); Z = cord(:, :, 3);
% low0 = [min(X(:)), min(Y(:)), min(Z(:))];
low0 = [cord(1, 1, 1), cord(1, 1, 2), cord(1, 1, 3)];
for iF = 1 : nF
    for iJ = 1 : nJ
        cord(iF, iJ, 1) = cord(iF, iJ, 1) - low0(1);
        cord(iF, iJ, 3) = cord(iF, iJ, 3) - low0(3);
    end
end
