function wsDOF = mocDOF(amcpath, asfpath, paraF)
% Load Degree of Freedom (DOF) of the specified mocap source.
%
% Input
%   source   -  mocap source
%   paraF    -  feature parameter
%   varargin
%     save option
%
% Output
%   wsDOF
%     DOF    -  DOF Matrix, dim x n
%     joint  -  joints related to DOFs
%     skel   -  skel struct for animation
%     cord   -  cordinates for animation
%     conn   -  connection of joints
%
% History
%   create   -  Feng Zhou, 12-29-2008
%   modify   -  SV, 05-19-2009


fprintf('acquiring the DOF...\n');

% data path

fprintf(['loading DOF of ' amcpath '...\n']);
if exist(amcpath, 'file')
    [DOF, joint] = amc2dof(amcpath);
    skel0 = asf2skel(asfpath);
    [skel, channels] = dof2skel(DOF, joint, skel0);
    [cord, conn] = parseCoordinate(skel, channels);

else
    error([amcpath ' does not exist.']);

end

% offset
offset = ps(paraF, 'offset', 1);
if offset ~= 1
    DOF = DOF(:, offset: end);
    cord = cord(offset : end, :, :);
end

% fps
fps = ps(paraF, 'fps', 120);
if fps ~= 120
    [DOF, fPos] = downSample(DOF, fps, 'fps');
    cord = cord(fPos, :, :);
end

% path
isPath = psY(paraF, 'path', 'n');
if isPath
    [DOF, angV, angP] = dofPathNew(DOF, st);
    skel0 = asf2skel(source);
    [skel, channels] = dof2skel(DOF, joint, skel0);
    [cord, conn] = parseCoordinate(skel, channels, angV, angP);
end

% store
wsDOF.DOF = DOF;
wsDOF.joint = joint;
wsDOF.skel = skel;
wsDOF.cord = cord;
wsDOF.conn = conn;

