function MOC = mocHuman
% Load human label file, and parse the range (head and end position) and
% discription of each segment.
%
% Output
%   MOC     -  human label for motion capture
%   seg     -  segmentation parameter
%   cnames  -  class names, 1 x k (cell)
%
% History
%   create  -  Feng Zhou, 12-29-2008
%   modify  -  Feng Zhou, 12-29-2008

% path
global footpath; % specified in addPath.m
txtpath = [footpath filesep 'data' filesep 'mocap' filesep 'mocap.txt'];
matpath = [footpath filesep 'data' filesep 'mocap' filesep 'mocap.mat'];

% if mat existed, just load
if exist(matpath, 'file')
    tmpMat = load(matpath);
    MOC = tmpMat.MOC;
    return;
end
fprintf('parsing file %s...\n', txtpath);

% open text file
fid = fopen(txtpath, 'rt');
if fid == -1
    error(['can not open file: ' txtpath]);
end

% line-by-line
while ~feof(fid)
    line = fgetl(fid);
    parts = tokenise(line, ' ');

    % skip empty line
    if isempty(parts), continue; end
    
    % parse one mocap
    if length(parts) == 2
        pno = parts{1};
        trial = parts{2};
        name = ['mocap_' pno '_' trial];
        
        [seg, cnames] = mocapOne(fid);
        MOC.(name).seg = seg;
        MOC.(name).cnames = cnames;

    else
        error('grammar error');
    end
end

save(matpath, 'MOC');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [seg, cnames] = mocapOne(fid)
% Parse one mocap's label.
% Input
%   fid     -  file handler
% Output
%   seg     -  segmentation parameter
%   cnames  -  class names, 1 x k (cell)

% initialize
maxk = 20; maxm = 100;
k = 0; m = 0;
cnames = cell(1, maxk);
L = zeros(1, maxm);
st = ones(1, maxm + 1);

while ~feof(fid)
    line = fgetl(fid);
    parts = tokenise(line, ' ');

    % finish one mocap
    if isempty(parts), break; end
    
    m = m + 1;
    
    % label
    cname = parts{1};
    c = strloc(cname, cnames);
    if c == 0 % new class?
        k = k + 1;
        cnames{k} = cname;
        c = k;
    end
    L(m) = c;
    
    % boundary
    p2 = floor(str2double(parts{3}));
    st(m + 1) = p2 + 1;
end

% remove no-used fields
cnames(k + 1 : end) = [];
st(m + 2 : end) = [];
L(m + 1 : end) = [];

seg.st = st;
seg.H = L2H(L, k);
