function wsPart = mocPart(wsFeat, paraF)
% Obtain the mocap features.
%
% Input
%   wsFeat
%   source
%   paraF
%   varargin
%
% Output
%   wsPart
%     posF
%     DX
%
% History
%   create  -  Feng Zhou, 02-13-2009
%   modify  -  SV, 05-19-2009


fprintf('obtain the part of mocap...\n');

% old mocap
X = wsFeat.X;
nF = size(X, 2);

% position
range = ps(paraF, 'range', []);
if ~isempty(range)
    head = max(1, range(1));
    tail = min(nF, range(2));
    posF = head : tail;
else
    posF = 1 : nF;
end
wsPart.posF = posF;

% temporal reduction
isR = psY(paraF, 'reduce', 'n');
if isR
    X = X(:, posF);
    
    % temporal reduction
    [X, stR, DX] = tempoReduce(X, paraF);
    X = stPick(X, stR);
    
    wsPart.DX = DX;
    wsPart.stR = stR;
    wsPart.X = X;
end

