function [path, isSave, prefix] = psSave(option, varargin)
% Parse the save option and generate the output path.
% Commonly, the path would be like: folder/prefix_subfix.mat
%
% Input
%   option    -  option 1, 'prefix' | 'save' | 'folder'
%   varargin  -  option 2
%     prefix  -  prefix of path, {[]}
%     subfix  -  subfix of path, {''}
%     folder  -  folder path, {[]}
%
% Output
%   path      -  mat path
%   isSave    -  save flag
%   prefix    -  prefix
%
% History
%   create    -  Feng Zhou, 12-29-2008
%   modify    -  Feng Zhou, 02-05-2009

% parameter in option
prefix1 = ps(option, 'prefix', []);
folder1 = ps(option, 'folder', []);
isSave = psY(option, 'save', 'n');

% parameter in varargin
prefix2 = ps(varargin, 'prefix', []);
folder2 = ps(varargin, 'folder', []);
subfix = ps(varargin, 'subfix', '');

% folder
if ~isempty(folder2)
    folder = folder2;
elseif ~isempty(folder1)
    folder = folder1;
else
    folder = '.';
end

% prefix
if isempty(prefix1) && isempty(prefix2)
    prefix = '';
elseif isempty(prefix1)
    prefix = prefix2;
elseif isempty(prefix2)
    prefix = prefix1;
else
    prefix = [prefix1 '_' prefix2];
end

% full path
global footpath; % specified in addPath.m
footpath2 = footpath;
prefix = sprintf('%s/save/%s/%s_%s', footpath2, folder, prefix, subfix);
path = sprintf('%s.mat', prefix);