function seg = segNewSt(seg0, stR, varargin)
% Adjust the segment position according to the compressed configuration.
%
% Input
%   seg0    -  original segmentation
%   stR     -  configuration of the compression
%   varargin
%     type  -  function type, {'shrink'} | 'expand'
%
% Output
%   seg     -  segmentation parameter
%
% History
%   create  -  Feng Zhou, 02-04-2009
%   modify  -  Feng Zhou, 03-02-2009

% function option
type = ps(varargin, 'type', 'shrink');

st0 = seg0.st;
H0 = seg0.H;
if strcmp(type, 'shrink')

    st0 = frame2block(st0(1 : end - 1), stR);
    st0 = [st0, length(stR)];

    st = [];
    H = [];
    for i = 1 : length(st0) - 1
        if st0(i) ~= st0(i + 1)
            st = [st, st0(i)];
            H = [H, H0(:, i)];
        end
    end
    st = [st, length(stR)];

elseif strcmp(type, 'expand')
    H = H0;
    st = stR(st0);

else
    error('unknown type');
end

seg.st = st;
seg.H = H;