% Synchronize system time in timestamps those with same trigger
function offsetRemover(path)

offsetFile = 'offsets.txt';
if path(end)~=filesep
    path(end+1)= filesep;
end

h = waitbar(0,'Synchronizing timestamps...');
waitbar(0/100);
disp('Synchronizing IMU 3DMG...');
removeOffsetImu(path,offsetFile, 'IMU_CB');

waitbar(20/100);

disp('Synchronizing IMU 6DOFv4...');
removeOffsetImu(path,offsetFile, 'IMU_BT');

waitbar(40/100);

disp('Synchronizing Cameras...');
removeOffsetCam(path, offsetFile);

waitbar(60/100);

disp('Synchronizing Audio...');
audioDecimateFactor = 200;
audioFreq = 44100;
removeOffsetAudio(path, offsetFile, audioDecimateFactor, audioFreq);

waitbar(70/100);

disp('Synchronizing Motion Capture...');
removeOffsetMC(path, offsetFile);

waitbar(90/100);

disp('Synchronizing RFID...');
removeOffsetRFID(path, offsetFile);

disp('Synchronizing eWatch...');
removeOffseteWatch(path, offsetFile);

waitbar(100/100);
close(h);

function removeOffsetRFID(mainPath, offsetFile)

    [ids offsets] = textread([mainPath offsetFile], '%s%s', 'headerlines', 1);
    isThis = strfind(ids, 'RFID');
    notfound=0;
    j=1;
    while isempty(isThis{j}) && j<=size(offsets, 1)
        j=j+1;
    end
    if j<=size(offsets, 1)
        off = str2double(offsets{j})*-1;

        dataDir=dir(mainPath);

        i =1;
        while (isempty(strfind(dataDir(i).name, 'RFID')) && isempty(strfind(dataDir(i).name, 'rfid')) || ~dataDir(i).isdir) && i < size({dataDir.name},2)
            i=i+1; 
        end
        if ~(isempty(strfind(dataDir(i).name, 'RFID')) && isempty(strfind(dataDir(i).name, 'rfid')) || ~dataDir(i).isdir)
            %path of rfid folder
            pathFile = strcat(mainPath, dataDir(i).name, filesep);

            dataDirRFID = dir(pathFile);
            %we search the rfid file rfid-presync.txt
            j=1;
            while (isempty(strfind(dataDirRFID(j).name, 'RFID-')) || isempty(strfind(dataDirRFID(j).name, '-presync'))) && j < size({dataDirRFID.name},2)
                j=j+1; 
            end
            if ~isempty(strfind(dataDirRFID(j).name, 'RFID-')) && ~isempty(strfind(dataDirRFID(j).name, '-presync'))
                RFIDFile=strcat(pathFile,dataDirRFID(j).name);
            else    
                notfound=1;
            end
        else    
            notfound=1;
        end

        if exist(RFIDFile, 'file') && ~notfound 
            if off~=0
                fid = fopen(RFIDFile);
                strDataRFID = textscan(fid, '%s %s %s');
                fclose(fid);

                RFIDFileSync = strrep(RFIDFile,'-presync.','-sync.');

                disp(['Creating file: ' RFIDFileSync]);
                fid = fopen(RFIDFileSync, 'w');

                timeString = strDataRFID{2};
                [samplePeriod, sampleFreq] = getPeriodSample(strDataRFID{2}{2}, strDataRFID{2}{1});
                for i = 1 : size(strDataRFID{1},1)
                    newTimeStr = addSysTime(off*samplePeriod, timeString{i});
                    fprintf(fid,'%s %s %s\n',strDataRFID{1}{1},newTimeStr,strDataRFID{3}{i});                
                end
                fclose(fid);


            end %else copy presync file?
        else
           fprintf('RFID not found, not synchronized'); 
        end
 
    end


function removeOffsetMC(mainPath, offsetFile)

% Get offsets
[ids offsets] = textread([mainPath offsetFile], '%s%s', 'headerlines', 1);
isThis = strfind(ids, 'MC');

j=1;
while isempty(isThis{j}) && j<=size(offsets, 1)
    j=j+1;
end
if j<=size(offsets, 1)
    off = str2double(offsets{j})*-1;
    
    mocapTime = strcat(mainPath,'mocap',filesep,'mocapTime.txt');
    
    if ~exist(mocapTime, 'file') 
        fprintf('Couldnt synchronize mocapTime.txt, file not found\n');
    else
        if off~=0
            fid = fopen(mocapTime);
            strDataMocap = textscan(fid, '%s %s');
            fclose(fid);
    
            mocapTimeSync = strcat(mainPath,'mocap',filesep,'mocapTime-sync.txt');

            disp(['   Creating file: ' mocapTimeSync]);
            fid = fopen(mocapTimeSync, 'w');

            timeString = strDataMocap{size(strDataMocap, 2)};
            [samplePeriod, sampleFreq] = getPeriodSample(strDataMocap{2}{2}, strDataMocap{2}{1});
            for i = 1 : size(strDataMocap{1},1)
                newTimeStr = addSysTime(off*samplePeriod, timeString{i});
                fprintf(fid,'%s %s\n',strDataMocap{1}{i},newTimeStr);                
             end
             fclose(fid);
        end
    end
    
    
    
else
    errordlg('ERROR reading offsets')
end

function removeOffsetImu(mainPath, offsetFile, type)

%   type = 'IMU_CB' || 'IMU_BT'

% Get offsets
[ids offsets] = textread([mainPath offsetFile], '%s%s', 'headerlines', 1);
isThis = strfind(ids, type);
if strcmp(type,'IMU_CB')
    type = '3DMGX1';
elseif strcmp(type,'IMU_BT')
    type = '6DOFv4';
else
    errordlg('ERROR: type of IMU missmatch template')
    return
end

j=1;
while isempty(isThis{j}) && j<=size(offsets, 1)
    j=j+1;
end
if j<=size(offsets, 1)
    off = str2double(offsets{j})*-1;
    
    % find files to synchronize
    dataDir = dir(mainPath);
    i =1;
    while isempty(strfind(dataDir(i).name, type)) && i < size({dataDir.name},2)
        i=i+1; 
    end
    if i<=size({dataDir.name},2)
        accelPath = strcat(mainPath, dataDir(i).name, filesep);
    else
        disp(['IMU Microstrain 3DMGX1 directory not found in:' mainPath]);
        %errdlg(['IMU Microstrain 3DMGX1 directory not found in:' mainPath]);
    end
    fileNames = dir(accelPath);
    k=0;
    for j=1:length(fileNames)    
        loadThis = 0;
        accelFile = [accelPath fileNames(j).name];
        if ~isdir(accelFile) && strcmp(accelFile(length(accelFile) -8:length(accelFile)), '-time.txt')
            loadThis = 1;            
        end
        if loadThis
            if off~=0
                % Synchronize this file
                k=k+1;
                %disp(['Reading file: ' accelFile]);
                fid = fopen(accelFile);
                strHeader{1} = fgetl(fid);
                strHeader{2} = fgetl(fid);
                fclose(fid);
                fid = fopen(accelFile);
                %reads columns
                strDataAccel = textscan(fid, '%s %s %s %s %s %s %s %s %s %s %s', 'HeaderLines', 2);
                fclose(fid);
                accelFile = [strrep(accelFile, '.txt', '') '-synch.txt'];
                disp(['   Creating file: ' accelFile]);
                fid = fopen(accelFile, 'wt');
                for i=1:2
                    fprintf(fid,'%s\n', strHeader{i});
                end
                timeString = strDataAccel{size(strDataAccel, 2)};
                [samplePeriod, sampleFreq] = getPeriodSample(timeString{2}, timeString{1});
                for i = 1 : size(strDataAccel{1},1)
                    for n = 1 : size(strDataAccel,2)-1
                        fprintf(fid,'%s\t',strDataAccel{n}{i});
                    end
                    newTimeStr = addSysTime(off*samplePeriod, timeString{i});
                    fprintf(fid,'%s\n',newTimeStr);                
                end
                fclose(fid);
            end
            clear strDataAccel
        end
    end
else
    errordlg('ERROR reading offsets')
end



function removeOffsetCam(cPath, offsetFile)
    
    dataDir = dir(cPath);
    i=1;
  
    while (isempty(strfind(dataDir(i).name, 'Video')) && isempty(strfind(dataDir(i).name, 'video')) || ~dataDir(i).isdir) && i < size({dataDir.name},2) 
        i=i+1; 
    end
    if ~(isempty(strfind(dataDir(i).name, 'Video')) && isempty(strfind(dataDir(i).name, 'video')) || ~dataDir(i).isdir)
        pathFile = strcat(cPath ,dataDir(i).name, filesep);
    else
        pathFile = strcat(cPath, filesep);
    end
    
    
    
[ids offsets] = textread([cPath offsetFile], '%s%s', 'headerlines', 1); % Get offsets

sTimeNames = dir(pathFile);

k =1;
for i=1:length(sTimeNames)
    if length(sTimeNames(i).name)>8 ...
            && ~isempty(strfind(sTimeNames(i).name, 'presynch.txt'))
        [frames{k} sysTime{k} ] = textread([pathFile sTimeNames(i).name], '%s%*s%*s%*s%s');
        numFrames{k} = zeros(size(frames{k}));
        lostFrames{k} = [];
        for j=1:size(frames{k},1)
            [token, remain] =strtok(frames{k}(j), ':');
            numFrames{k}(j) = str2double(remain{1}(2:end));
            if j~=1 
                lost = numFrames{k}(j)-numFrames{k}(j-1);
                if lost>1
                    for l = lost-1:-1:1
                        lostFrames{k} = [lostFrames{k} (numFrames{k}(j)-l)];
                    end
                end
            end
        end
        fileName{k} = [pathFile sTimeNames(i).name];
        k = k+1;
    end
end
k = k-1;


for i=1:k

    % Get frame period
    [framePeriod, frameRate] = getPeriod(sysTime{i}{2}, sysTime{i}{1});
    
    % Get offset
    token = findstr(fileName{i}, filesep);
%   Find out the name of this camera from the video file name
    cameraName = fileName{i}(token(length(token))+1 : end);
    cameraName = strrep(cameraName, 'STime', '');
    cameraName = strrep(cameraName, '-time-presynch.txt', '');
    isThis = strfind(ids, cameraName);
    j=1;
    while isempty(isThis{j}) && j<=size(offsets, 1)
        j=j+1;
    end
    if j<=size(offsets, 1)
        off = str2double(offsets{j})*-1;

        % Change systime adding offset*frame period to the 
        if (off~=0) 
            for j=1:size(sysTime{i}, 1)
                sysTime{i}{j} = addSysTime(off*framePeriod, sysTime{i}{j});
            end
        end

        save2fileCamTs(strrep(fileName{i}, 'presynch', ''), sysTime{i}, numFrames{i}, 'synch.txt');
    else
        error('Offset bad!!')
    end

end

function removeOffseteWatch(path, offsetFile)
    %pica pala
    %pica pala
    
    % Get offsets
    [ids offsets] = textread([path offsetFile], '%s%s', 'headerlines', 1);
    isThis = strfind(ids, 'eWatch');
    period=1/60;
    j=1;
    while isempty(isThis{j}) && j<=size(offsets, 1)
        j=j+1;
    end
    if j<=size(offsets, 1)
        off = str2double(offsets{j})*-1;
        
        if off~=0
        
            dataDir=dir(path);
            i =1;
            while (isempty(strfind(dataDir(i).name, 'eWatch')) && isempty(strfind(dataDir(i).name, 'ewatch')) || ~dataDir(i).isdir) && i < size({dataDir.name},2)
                    i=i+1; 
            end
            if ~(isempty(strfind(dataDir(i).name, 'eWatch')) && isempty(strfind(dataDir(i).name, 'ewatch')) || ~dataDir(i).isdir)
                eWatchFolder = strcat(path, dataDir(i).name, filesep);
                dataDir = dir(eWatchFolder);
                if ~isempty(dataDir)
                    i =1;
                    while isempty(strfind(dataDir(i).name, 'eWatch_')) || ~isempty(strfind(dataDir(i).name, 'sync')) && i < size({dataDir.name},2)
                        i=i+1; 
                    end
                    if i<=size({dataDir.name},2)
                        ewatchFile = strcat(eWatchFolder, dataDir(i).name);

                        fid = fopen(ewatchFile);
                        startTime = [fgetl(fid) '0000'];
                        newtimeStart = addSysTime(off*period, startTime); 

                        [pathstr, name, ext, versn] = fileparts(ewatchFile);
                        neweWatchfile = [pathstr filesep name '-sync' ext];


                        %copyfile(ewatchFile,neweWatchfile);
                        nfid = fopen(neweWatchfile, 'w');
                        fprintf(nfid,'%s\n',newtimeStart);
                        while ~feof(fid)
                           line=fgetl(fid);
                           fprintf(nfid,'%s\n',line);
                        end

                        fclose(nfid);
                        fclose(fid);

                    else
                        disp('eWatch file not found, couldnt presynchronize');
                    end
                end
            else
                disp('eWatch folder not found, couldnt presynchronize');
            end
        end
    else
        disp('No offset for eWatch');
    end


function removeOffsetAudio(path, offsetFile, audioDecimateFactor, audioFreq)
    
    dataDir=dir(path);
    i =1;
    while (isempty(strfind(dataDir(i).name, 'Audio')) && isempty(strfind(dataDir(i).name, 'audio')) || ~dataDir(i).isdir) && i < size({dataDir.name},2)
        i=i+1; 
    end
    if ~(isempty(strfind(dataDir(i).name, 'Audio')) && isempty(strfind(dataDir(i).name, 'audio')) || ~dataDir(i).isdir)

        [timeStart, timeStop] = getAudioTimeInit([path 'audio' filesep 'recording.log']); % read recording.log

        [ids offsets] = textread([path offsetFile], '%s%s', 'headerlines', 1); % Get offsets
        isThis = strfind(ids, 'Audio');
        j=1;
        while isempty(isThis{j}) && j<=size(offsets, 1)
            j=j+1;
        end
        if j<=size(offsets, 1)
            off = str2double(offsets{j})*-1;


                if off~=0
                    period = 1/audioFreq*audioDecimateFactor;
                    timeStart = addSysTime(off*period, timeStart); % modify start and stop time
                    timeStop = addSysTime(off*period, timeStop);
                end
                fileName = [path 'audio' filesep 'recording-synch.log'];
                fid = fopen(fileName,'wt');
                fprintf(fid,'Recording stream opened at:\t%s\n', timeStart);
                fprintf(fid,'Closing recording stream at:\t%s\n', timeStop);
                fclose(fid);
                disp(['Audio file: ' path 'audio' filesep 'recording-synch.log ... Finished!'])
        else
            errordlg(['Offset for audio not found in ' [path offsetFile]])
        end
    else
        disp('Audio folder not found, couldnt presynchronize');
    end


function [samplePeriod, sampleFreq] = getPeriodSample(sysTimeII, sysTimeI)
% framePeriod in 1/10*microseconds

hhII = str2double(sysTimeII(1:2));
mmII = str2double(sysTimeII(4:5));
ssII = str2double(sysTimeII(7:8));
uuII = str2double(sysTimeII(10:16));

hhI = str2double(sysTimeI(1:2));
mmI = str2double(sysTimeI(4:5));
ssI = str2double(sysTimeI(7:8));
uuI = str2double(sysTimeI(10:16));


uuII = uuII + 10^7*ssII + 60*10^7*mmII + 60*60*10^7*hhII;
uuI = uuI + 10^7*ssI + 60*10^7*mmI + 60*60*10^7*hhI;

samplePeriod = (uuII - uuI)/10^7;
sampleFreq = round(1/samplePeriod);




function [framePeriod, frameRate] = getPeriod(sysTimeII, sysTimeI)
% framePeriod in 1/10*microseconds

hhII = str2double(sysTimeII(1:2));
mmII = str2double(sysTimeII(4:5));
ssII = str2double(sysTimeII(7:8));
uuII = str2double(sysTimeII(10:16));

hhI = str2double(sysTimeI(1:2));
mmI = str2double(sysTimeI(4:5));
ssI = str2double(sysTimeI(7:8));
uuI = str2double(sysTimeI(10:16));


uuII = uuII + 10^7*ssII + 60*10^7*mmII + 60*60*10^7*hhII;
uuI = uuI + 10^7*ssI + 60*10^7*mmI + 60*60*10^7*hhI;

framePeriod = (uuII - uuI)/10^7;
frameRate = round(1/framePeriod);

frameRateTemplate = [30, 60];

[val, in] = min (abs(frameRateTemplate- frameRate));

frameRate = frameRateTemplate(in);

%framePeriod = floor(1/frameRate*10^7)/10^7;

if frameRate == 30
    framePeriod = 0.033332;
else
    framePeriod = 0.016666;
end


function nextTime = addSysTime(framePeriod, sysTime)

hhC = str2double(sysTime(1:2));
mmC = str2double(sysTime(4:5));
ssC = str2double(sysTime(7:8));
uuC = str2double(sysTime(10:16));

uu = framePeriod*10^7 + uuC + ssC*10^7 + mmC*60*10^7 + hhC*60*60*10^7;

ss = floor( uu/10^7 );

uuN = (uu/10^7 - floor(uu/10^7)) *10^7;
uuN = round(uuN);
ssN = mod(ss, 60);
mm = floor(ss/60);
mmN = mod(mm, 60);
hhN = floor(mm/60);

uuStr = num2str(uuN, '%d');
if length(uuStr) < 7
    trunc = 7 - length(uuStr);
    for ii = 6-trunc+1 : 6
        tmp = strcat('0', uuStr(length(uuStr)- (6-trunc) : length(uuStr)));
        uuStr = strcat(uuStr(1: length(uuStr)-(6-trunc+1) ), tmp);
    end
end

ssStr = num2str(ssN, '%d');
if length(ssStr) < 2
    ssStr = ['0' ssStr];
end

mmStr = num2str(mmN, '%d');
if length(mmStr) < 2
	mmStr = ['0' mmStr];
end

hhStr = num2str(hhN, '%d');
if length(hhStr) < 2
	hhStr = ['0' hhStr];
end

nextTime = [ hhStr '_' mmStr '_' ssStr '_' uuStr];


function save2fileCamTs(fileName, sysTime, numFrames, sufix)

fileName = [fileName(1:length(fileName)-4) sufix];
fprintf('Creating file: %s...\n', fileName);    
fid = fopen(fileName,'wt');
for i=1:size(sysTime, 1)
    fprintf(fid,'Frame:%d Fwt:----.---- EPOCH: -- %s\n', ...
        numFrames(i), sysTime{i});
end
fclose(fid);


function [timeStart, timeStop] = getAudioTimeInit(audioTimeFile)
fid = fopen(audioTimeFile);
strAudioTime = textscan(fid, '%*s %*s %*s %*s %*s %*s %*s %s %*s %s', 'HeaderLines', 1);
fclose(fid);

usec = sprintf('%0.7f',str2double(strAudioTime{2}{1}(7:end-1))*10^-6);
timeStart = sprintf('%s.%s', strAudioTime{1}{1}, usec(3:end));
%timeStart = timestamp2sec(timeStart);

usec = sprintf('%0.7f',str2double(strAudioTime{2}{2}(7:end-1))*10^-6);
timeStop = sprintf('%s.%s', strAudioTime{1}{2}, usec(3:end));
%timeStop = timestamp2sec(timeStop);
